@@ -29,7 +29,6 @@
 #include <QColorDialog>
 #include <QInputDialog>
 #include <QMessageBox>
-#include <QPixmap>
 #include <QTextDocument>
 #include <iostream>
 
@@ -146,3 +145,5 @@ KsirkChatItem& KsirkChatItem::operator<<(const QPixmap& pixmap)
   m_order.push_back(Pixmap);
   return *this;
 }
+
+#include "moc_KsirkChatItem.cpp"
