@@ -21,9 +21,7 @@
 #include <QDomElement>
 #include <QString>
 
-#include "xmpp_task.h"
 #include "xmpp/jid/jid.h"
-#include "xmpp_discoitem.h"
 #include "xmpp_discoinfotask.h"
 #include "xmpp_xmlcommon.h"
 
