@@ -45,7 +45,7 @@ int main(int argc, char *argv[])
                        KAboutLicense::GPL,
                        i18n("(c) 2002-2015, Gaël de Chalendar\n"),
                        i18n("For help and user manual, please see\nthe KsirK web site."),
-                       QStringLiteral("https://kde.org/applications/games/org.kde.ksirk"));
+                       QStringLiteral("https://apps.kde.org/ksirk"));
 
   aboutData.addAuthor(i18n("Gaël de Chalendar aka Kleag"),QStringLiteral(), QStringLiteral("kleag@free.fr"));
   aboutData.addAuthor(i18n("Nemanja Hirsl"),i18n("Current maintainer"), QStringLiteral("nemhirsl@gmail.com"));
@@ -55,9 +55,6 @@ int main(int argc, char *argv[])
   aboutData.addAuthor(i18n("French students of the 'IUP ISI 2007-2008':"));
   aboutData.addAuthor(i18n("&nbsp;&nbsp;Anthony Rey<br/>&nbsp;&nbsp;Benjamin Lucas<br/>&nbsp;&nbsp;Benjamin Moreau<br/>&nbsp;&nbsp;Gaël Clouet<br/>&nbsp;&nbsp;Guillaume Pelouas<br/>&nbsp;&nbsp;Joël Marco<br/>&nbsp;&nbsp;Laurent Dang<br/>&nbsp;&nbsp;Nicolas Linard<br/>&nbsp;&nbsp;Vincent Sac"));
 
-  aboutData.setOrganizationDomain(QByteArray("kde.org"));
-  aboutData.setProductName(QByteArray("ksirk"));
-
   app.setWindowIcon(QIcon::fromTheme(QStringLiteral("ksirk")));
   KAboutData::setApplicationData(aboutData);
   KCrash::initialize();
