@@ -40,7 +40,7 @@ m_automaton(automaton), m_skin(""), m_worlds(), m_players(),
   {
     if (skinsDirName.isEmpty())
     {
-      KMessageBox::error(0,
+      KMessageBox::error(nullptr,
                          i18n("Skins directory not found - Verify your installation\nProgram cannot continue"),
                          i18n("Fatal Error!"));
                          exit(2);
